from typer import Typer, Argument
from typing_extensions import Annotated

from imagetools.cli.apply import apply_configuration
from imagetools.cli.flask import flask
from imagetools.lib.exif import get_date, has_date
from imagetools.lib.filesystem import filter_ls, scramble, sequential_rename

app = Typer()


@app.command()
def rename(
    directories: Annotated[list[str], Argument(help="The directories to rename")],
) -> None:
    for directory in directories:
        scramble(directory)

        files = filter_ls(directory, has_date, get_date)

        sequential_rename(files)


@app.command()
def date(
    configuration: Annotated[str, Argument(help="Path of configuration file to edit")],
    directories: Annotated[
        list[str], Argument(help="The directories to scan for undated files")
    ],
) -> None:
    flask.config["filter_file"] = configuration
    flask.config["base_folders"] = directories

    flask.run(debug=True)


def apply(
    configuration: Annotated[str, Argument(help="Path of configuration file to apply")],
    directories: Annotated[
        list[str], Argument(help="The directories to apply changes to")
    ],
) -> None:
    apply_configuration(configuration)


if __name__ == "__main__":
    app()
