import os
import random
from flask import Flask, request, render_template, redirect

from imagetools.lib.constants import TEMPLATE_FOLDER, SEPARATOR
from imagetools.lib.exif import get_date
from imagetools.lib.filesystem import filter_ls, append_to_file

flask = Flask(__name__, template_folder=TEMPLATE_FOLDER)


def _already_sorted(file_path: str):
    """
    Checks if a given file has been
    """
    filter_file = flask.config.get("filter_file")

    with open(filter_file, "r") as f:
        for line in f.readlines():
            file, _ = line.split(SEPARATOR)

            if file == file_path:
                return True

    return False


def _adjacent_dates(file: str) -> list[tuple[str, str]]:
    """
    Gets the EXIF data from files within the same directory as a given file.

    :param file: The path of an image
    :returns: List containing [filename, date] tuples of adjacent files.
    """
    directory = os.path.abspath(os.path.dirname(file))

    return [
        [i, get_date(os.path.join(directory, i), allow_none=True)]
        for i in filter_ls(directory)
    ]


@flask.get("/")
def get():
    files_to_date = [
        i
        for j in flask.config.get("base_folders")
        for i in filter_ls(j, _already_sorted)
    ]

    image = random.choice(files_to_date)
    return render_template(
        "index.html",
        path=image,
        adjacent=_adjacent_dates(image),
        count=len(files_to_date),
    )


@flask.post("/date")
def post_date():
    d = request.form

    append_to_file(
        flask.config.get("filter_file"),
        f"{d['path']} -> {d['year']}-{d['month']}-{d['day']} {d['hours']}:{d['minutes']}:{d['seconds']}",
    )

    return redirect("/")


@flask.post("/delete")
def post_delete():
    d = request.form

    append_to_file(flask.config.get("filter_file"), f"{d['path']} -> DELETE")

    return redirect("/")
